===========
Nuvoton ISP
===========


.. image:: https://img.shields.io/pypi/v/nuvoton_isp.svg
        :target: https://pypi.python.org/pypi/nuvoton_isp

.. image:: https://img.shields.io/travis/fishman/nuvoton_isp.svg
        :target: https://travis-ci.org/fishman/nuvoton_isp

.. image:: https://ci.appveyor.com/api/projects/status/fishman/branch/master?svg=true
    :target: https://ci.appveyor.com/project/fishman/nuvoton_isp/branch/master
    :alt: Build status on Appveyor

.. image:: https://readthedocs.org/projects/nuvoton-isp/badge/?version=latest
        :target: https://nuvoton-isp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/fishman/nuvoton_isp/shield.svg
     :target: https://pyup.io/repos/github/fishman/nuvoton_isp/
     :alt: Updates



Nuvoton ISP library and CLI


* Free software: MIT license

* Documentation: https://fishman.github.io/nuvoton_isp



Installation:
-------------

.. code-block:: console

    $ pip install nuvoton-isp

USAGE:
------

.. code-block:: console

    $ nuvoisp -f firmware.bin

Features
--------

* Flash APROM

Credits
-------

This package was created with Cookiecutter_ and the `wboxx1/cookiecutter-pypackage-poetry`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`wboxx1/cookiecutter-pypackage-poetry`: https://github.com/wboxx1/cookiecutter-pypackage-poetry
